@@ -12,10 +12,9 @@ from struct import unpack
 import pprint
 
 from km3pipe import Pump, Blob
-from km3pipe.logger import get_logger
+from km3pipe.logger import logging
 
-
-log = get_logger(__name__)  # pylint: disable=C0103
+log = logging.getLogger(__name__)  # pylint: disable=C0103
 
 DATA_TYPES = {
     101: 'DAQSuperFrame',
@@ -70,10 +69,12 @@ class DAQPump(Pump):
         return blob
 
     def seek_to_frame(self, index):
+        """Move file pointer to the frame with given index."""
         pointer_position = self.frame_positions[index]
         self.blob_file.seek(pointer_position, 0)
 
     def get_blob(self, index):
+        """Return blob at given index."""
         self.seek_to_frame(index)
         return self.next_blob()
 
@@ -89,7 +90,7 @@ class DAQPump(Pump):
         except struct.error:
             pass
         self.rewind_file()
-        print("Found {0} frames.".format(len(self.frame_positions)))
+        log.info("Found {0} frames.".format(len(self.frame_positions)))
 
     def process(self, blob):
         """Pump the next blob to the modules"""
@@ -143,7 +144,8 @@ class DAQPreamble(object):
         self._parse_byte_data(byte_data)
 
     def __repr__(self):
-        description = "Length: {0}\nDataType: {1}".format(self.length, self.data_type)
+        description = "Length: {0}\nDataType: {1}"\
+            .format(self.length, self.data_type)
         return description
 
 
@@ -253,11 +255,13 @@ class DAQEvent(object):
         self._parse_snapshot_hits(file_obj)
 
     def _parse_triggered_hits(self, file_obj):
+        """Parse and store triggered hits."""
         for i in xrange(self.n_triggered_hits):
             dom_id, pmt_id, tdc_time, tot = unpack('<ibib', file_obj.read(10))
             self.triggered_hits.append((dom_id, pmt_id, tdc_time, tot))
 
     def _parse_snapshot_hits(self, file_obj):
+        """Parse and store snapshot hits."""
         for i in xrange(self.n_snapshot_hits):
             dom_id, pmt_id, tdc_time, tot = unpack('<ibib', file_obj.read(10))
             self.snapshot_hits.append((dom_id, pmt_id, tdc_time, tot))
