@@ -7,9 +7,9 @@ Common unit testing support for km3pipe.
 from __future__ import division, absolute_import, print_function
 
 try:
-    from unittest2 import TestCase
+    from unittest2 import TestCase, skipIf
 except ImportError:
-    from unittest import TestCase
+    from unittest import TestCase, skipIf
 
 try:
     from cStringIO import StringIO
